<?php
  // File: index.php

  declare(strict_types=1);
  error_reporting(E_ALL);
  ini_set('display_errors', '1');

  function sanitizeValue($value) {
    return htmlspecialchars( stripslashes( trim($value) ) );
  }// end sanitizeValue()

  function loadStatesFromFile(string $filename) : array {
    $fh = fopen($filename, 'r');
    $jsonStatesString = fread($fh, filesize($filename));
    fclose($fh);

    return json_decode($jsonStatesString, true);
  }// end loadStatesFromFile()

  function buildTable(array $states) : string {
    $table = "<table class='w3-table-all w3-hoverable'><thead><tr class='w3-khaki'>";

    foreach($states[0] as $col => $value) {
      $col = ucfirst($col);
      $table .= "<th>$col</th>";
    }
    $table .= "</tr></thead><tbody>";
    
    foreach($states as $index => $stateStats) {
      $table .= "<tr>";
      foreach($stateStats as $stateStat) {
        $table .= "<td>$stateStat</td>";
      }
      $table .= "</tr>";
    }

    $table .= "</tbody></table>";
    return $table;
  }// end buildTable()


  
  $curYear = date('Y');
  $phpScript = $_SERVER['PHP_SELF'];
  $hideStatus = '';

  $states = loadStatesFromFile('states.json');
  
  if ( $_SERVER['REQUEST_METHOD'] === 'POST') {
    echo buildTable($states);
    $hideStatus = "w3-hide"; 
  }
?>

<!DOCTYPE html>
<html>
<head>
<title>State Information</title>
<meta charset="utf-8" name="viewport" content="width=device-width, initial-scale=1.0">
<link rel="stylesheet" href="https://www.w3schools.com/w3css/4/w3.css">
</head>

<body class="w3-panel">
  <form action="<?php echo $phpScript; ?>" method="POST"
        class="w3-panel w3-center">
    <button class="w3-button w3-green <?php echo $hideStatus; ?>">Load State Information</button>
  </form>

  <footer class="w3-panel w3-center w3-text-gray w3-small">
    &copy; 2014-<?php echo $curYear; ?> Socratis Tornaritis
  </footer>
</body>
</html>