<?php
    // File: index.php
    // Demonstrates how to process a basic form with non-sticky input fields.
    // Note: put all this PHP code into a script, e.g. inc.form-nonsticky.php
    // and include it here.
    declare(strict_types = 1);
    error_reporting(E_ALL);
    ini_set('display_errors', '1');

    function sanitizeInput($value) {
        return htmlspecialchars( stripslashes( trim( $value) ) );
    }
    
    function checkedStatus(array $checkboxes, string $value) {
        // Check is the given value is one of the checked options
        // and return the string 'checked' if it is, empty string ''
        // if it isn't.
        return in_array($value, $checkboxes)? 'checked' : '';
    }

    $curYear = date('Y');
    $phpScript = sanitizeInput($_SERVER['PHP_SELF']);

    // Initialize processing variables to empty strings. These are the values
    // displayed when the form is GET requested.
    $checkbox = '';
    $checkboxes = [];

    // Process the form.
    if ($_SERVER['REQUEST_METHOD'] === 'POST') {
        // Was the form filled in ?
        if ( isset($_POST['checkbox']) ) {
            // extract all values. Checkbox sanitation must be at the string level, not
            // the array level. So, turn the array into a string for sanitation, then
            // convert the string back into an array.
            $checkboxes = explode(',', sanitizeInput( join(',', $_POST['checkbox']) ) );


            // Multiple checkboxes may be checked.
            foreach($checkboxes as $checked) {
                $checkbox .= "$checked, ";
            }
            // Now, remove the last comma space ', '.
            $checkbox = rtrim($checkbox, ', ');

        } else {
            $checkbox = "Error-Check an option";
        }
    }
?>


<!DOCTYPE html>
<html>
    <head>
        <meta charset="utf-8" name="viewport" content="width=device-width, initial-scale=1.0">
        <title>Non-Sticky Form</title>
        <link href="https://www.w3schools.com/w3css/4/w3.css" rel="stylesheet">
    </head>

    <body id="index_page">
            <main id="content" class="w3-panel">
                <aside>
                     <p>Checkbox choice: <?php echo $checkbox; ?></p>
                </aside>
                
                <form action="<?php echo $phpScript; ?>" method="POST" class="w3-border">
                    <!-- Checkboxes -->
                    <p>
                        <input type="checkbox" name="checkbox[]" value="check 1" <?php echo checkedStatus($checkboxes, 'check 1'); ?>> check 1
                        <input type="checkbox" name="checkbox[]" value="check 2" <?php echo checkedStatus($checkboxes, 'check 2'); ?>> check 2
                    </p>

                    <!-- Submit button -->
                    <button>Submit Form</button>
                </form>
            </main>

            <footer class="w3-panel w3-center w3-text-gray w3-small">
                &copy; <?php echo $curYear; ?> Socratis Tornaritis
            </footer>
    </body>
</html>