<?php
    // File: coursesForStudent.php

    declare(strict_types = 1);
    error_reporting(E_ALL);
    ini_set('display_errors', '1');

    $curYear = date('Y');
    $id = sanitizeInput($_GET['id']);

    function sanitizeInput($value) {
        return trim( htmlspecialchars( stripslashes($value) ) );
    }

    function buildStudentCard($id) {
        $pdoStatement = getCoursesForStudent($id);
        $row = $pdoStatement->fetch();

        $studentName = $row['name'];
        $sid = $row['sid'];

        // Build a card and show the student record.
        $card = "
            <div class='w3-card-4' style='width:40%'>
                <header class='w3-container w3-light-grey'>
                    <h2>$studentName ($sid)</h2>
                </header>
                
                <table class='w3-table-all w3-hoverable'>
                    <thead>
                        <tr class='w3-red'>
                            <th>Term</th>
                            <th>Course</th>
                            <th>Title</th>
                            <th>Grade</th>
                        </tr>
                    </thead>
            ";

            do {
                $term = $row['term'];
                $number = $row['number'];
                $title = $row['title'];
                $grade = $row['grade'];

                $card .= "
                    <tr>
                        <td>$term</td>
                        <td>$number</td>
                        <td>$title</td>
                        <td>$grade</td>
                    </tr>
                ";
            } while( $row = $pdoStatement->fetch(PDO::FETCH_ASSOC) );

            $card .= "
                </table>
                <a href='listStudent.php' class='w3-button w3-block w3-dark-grey'>Ok</a>
            </div>
        ";

        return $card;
    }

    function getCoursesForStudent($id) : PDOStatement {
        
        try {
            // Include the db connection script
            require 'inc.db.php';

            // Connect to the db.
            $pdo = new PDO(DSN, USER, PWD);

            // Configure error handling
            $pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);

            // Create the query
            $sql = "
                SELECT s.sid, CONCAT(s.first, ' ', s.last) AS name, c.number, c.title, t.term, t.grade
                FROM student AS s, course AS c, transcript AS t
                WHERE s.id=t.student\$id
                AND c.id=t.course\$id
                AND s.id=$id
            ";

            // Execute the query.
            $pdoStatement = $pdo->query($sql);
            $pdo = null;
            
            return $pdoStatement;
            
        } catch(PDOException $e) {
            die ($e->getMessage() );
        }
    }
?>


<!DOCTYPE html>
<html>
<head>
    <title>PHP-MySQL Demo</title>
    <meta charset="utf-8" name="viewport" content="width=device-width, initial-scale=1.0">
    <link rel="stylesheet" href="https://www.w3schools.com/w3css/4/w3.css">
</head>
<body class="w3-panel">
    <?php echo buildStudentCard($id); ?>

    <footer class="w3-panel w3-center w3-text-grey w3-small">
        &copy; 2014-<?php echo $curYear; ?> Socratis Tornaritis.
    </footer>
</body>
</html>