<?php
    // File: courseRecord.php

    declare(strict_types = 1);
    error_reporting(E_ALL);
    ini_set('display_errors', '1');

    $curYear = date('Y');
    $id = sanitizeInput($_GET['id']);

    function sanitizeInput($value) {
        return trim( htmlspecialchars( stripslashes($value) ) );
    }

    function buildCourseCard($id) {
        $pdoStatement = getStudentsInCourse($id);
        $row = $pdoStatement->fetch();

        $number = $row['number'];
        $title = $row['title'];

        $number = $number? $number : "Course";
        $title = $title? $title : "Title";
        
        // Build a card and show the student record.
        $card = "
            <div class='w3-card-4' style='width:45%'>
                <header class='w3-container w3-light-grey'>
                    <h2>$number-$title</h2>
                </header>

                <table class='w3-table-all w3-hoverable'>
                    <thead>
                        <tr class='w3-red'>
                            <th>Term</th>
                            <th>SID</th>
                            <th>First</th>
                            <th>Last</th>
                            <th>Email</th>
                        </tr>
                    </thead>
            ";

        do {
            $term = $row['term'];
            $sid = $row['sid'];
            $first = $row['first'];
            $last = $row['last'];
            $email = $row['email'];

            $card .= "
                <tr>
                    <td>$term</td>
                    <td>$sid</td>
                    <td>$first</td>
                    <td>$last</td>
                    <td>$email</td>
                </tr>
            ";
        } while( $row = $pdoStatement->fetch(PDO::FETCH_ASSOC) );

        $card .= "
                </table>
                <a href='listCourse.php' class='w3-button w3-block w3-dark-grey'>Ok</a>
                </div>
            </div>
        ";

        return $card;
    }

    function getStudentsInCourse($id) : PDOStatement {
        
        try {
            // Include the db connection script
            require 'inc.db.php';

            // Connect to the db.
            $pdo = new PDO(DSN, USER, PWD);

            // Configure error handling
            $pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);

            // Create the query
            $sql = "
                SELECT c.number, c.title, s.sid, s.first, s.last, s.email, t.term
                FROM student AS s, course AS c, transcript AS t
                WHERE c.id=t.course\$id
                AND s.id=t.student\$id
                AND c.id = $id;
            ";

            // Execute the query.
            $pdoStatement = $pdo->query($sql);
            $pdo = null;
            
            return $pdoStatement;
            
        } catch(PDOException $e) {
            die ($e->getMessage() );
        }
    }
?>


<!DOCTYPE html>
<html>
<head>
    <title>PHP-MySQL Demo</title>
    <meta charset="utf-8" name="viewport" content="width=device-width, initial-scale=1.0">
    <link rel="stylesheet" href="https://www.w3schools.com/w3css/4/w3.css">
</head>
<body class="w3-panel">
    <?php echo buildCourseCard($id); ?>

    <footer class="w3-panel w3-center w3-text-grey w3-small">
        &copy; 2014-<?php echo $curYear; ?> Socratis Tornaritis.
    </footer>
</body>
</html>