<?php
    // File: index.php
    /* Demonstrates the creation of a DB, two tables and the
     * insertion of a record into each table. One form is used
     * to collect fields for both tables.
    */

    declare(strict_types = 1);
    error_reporting(E_ALL);
    ini_set('display_errors', '1');

    function sanitizeInput($value) {
        return htmlspecialchars( stripslashes( trim( $value) ) );
    }

    function getPDO(): PDO {
        return new PDO('mysql:host=localhost;dbname=uni', 'root', 'root');
    }

    function createDB(string $db) {
        // We will establish a connection to the server and create
        // the dabase first.
        $pdo = new PDO('mysql:host=localhost', 'root', 'root');
        $sql = "CREATE DATABASE IF NOT EXISTS $db";
        $status = $pdo->exec($sql) or die('Server error.');
        $pdo = null;
        echo "DB create status: $status<br>";
    }

    function createInstructorTable(PDO $pdo) {
        $sql = "
        CREATE TABLE IF NOT EXISTS instructor (
            id INT UNSIGNED AUTO_INCREMENT NOT NULL,
            name VARCHAR(30),
            PRIMARY KEY(id)
        )
        ";
        $status = $pdo->exec($sql);
        echo "Table instructor create status: $status<br>";
    }

    function createCourseTable(PDO $pdo) {
        $sql = "
        CREATE TABLE IF NOT EXISTS course (
            id INT UNSIGNED AUTO_INCREMENT NOT NULL,
            number VARCHAR(8),
            instructor\$id INT UNSIGNED NOT NULL,
            PRIMARY KEY(id),
            FOREIGN KEY (instructor\$id) REFERENCES instructor(id)
        )
        ";
        $status = $pdo->exec($sql);
        echo "Table course create status: $status<br>";
    }

    function insertInstructorRecord(PDO $pdo, string $name): int {
        // Notice the single quotes around the name.
        $sql = "
        INSERT INTO instructor
          (name)
        VALUES
          ('$name')
        ";
        $pdo->exec($sql);
        $id = (int)$pdo->lastInsertId();
        echo "Instructor id: $id.<br>";
        return $id;
    }

    function insertCourseRecord(PDO $pdo, int $instructorId, string $number) {
        // Notice the single quotes around the name.
        $sql = "
        INSERT INTO course
          (instructor\$id, number)
        VALUES
          ($instructorId, '$number')
        ";
        $pdo->exec($sql);
        $id = $pdo->lastInsertId();
        echo "Course id: $id.<br>";
    }

    function getInstructorId(PDO $pdo, string $name): int {
        // Search for the instructor and return its id if found,
        // or 0 if not.
        $sql = "
        SELECT id
        FROM instructor
        WHERE name = '$name'
        ";
        $stm = $pdo->query($sql, PDO::FETCH_ASSOC);
        if ($stm->rowCount() == 1) { return (int)$stm->fetch()['id']; }
        else                       { return 0;                   }
    }

    $phpScript = sanitizeInput($_SERVER['PHP_SELF']);



    if ($_SERVER['REQUEST_METHOD'] === 'POST') {
        try {
            // Create the uni database.
            $db = 'uni';
            createDB($db);
            
            $pdo = getPDO();
            $pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);

            // Create the instructor table.
            createInstructorTable($pdo);

            // Create the course table.
            createCourseTable($pdo);

            // Extract the fields.
            $name = sanitizeInput($_POST['name']);
            $number = sanitizeInput($_POST['number']);
            
            // Check if instructor is new or existing.
            $instructorId = getInstructorId($pdo, $name);

            if ($instructorId) {
                // Instructor is existing.
                insertCourseRecord($pdo, $instructorId, $number);

            } else {
                // Insert new instructor first.
                $instructorId = insertInstructorRecord( $pdo,  $name);

                // Next insert the course.
                insertCourseRecord($pdo, $instructorId, $number);
            }

            $pdo = null;

        } catch(PDOEXCEPTION $e) {
            // For debugging purposes reveal the message.
            die( $e->getMessage() );
        }
    }
?>

<!-- Simplified for brevity only -->
<h1>Insert Instructor/Course Form</h1>
<form action="<?php echo $phpScript; ?>" method="POST">
    <input name="name" placeholder = "Instructor name" autofocus>
    <input name="number" placeholder = "Course number">
    <button>Insert</button>
</form>