<?php
    // File: updateTransciptForm.php

    declare(strict_types=1);
    error_reporting(E_ALL);
    ini_set('display_errors', '1');

    $studentId = $courseid = $term = $grade = $formError = '';
    $phpScript = sanitizeInput($_SERVER['PHP_SELF']);

    function sanitizeInput($data) {
        return htmlspecialchars( stripslashes( trim( $data) ) );
    }// end sanitizeInput()
    

    function loadTranscriptRecord($id) {
        try {
            require 'inc.db.php';
            
            // Connect to the database
            $pdo = new PDO(DSN, USER, PWD);
            
            // Configure error handling
            $pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
            
            // Create the query
            $sql = "
                SELECT student\$id AS studentId, course\$id AS courseId, term, grade
                FROM transcript
                WHERE id=$id
            ";
            
            // Execute the query.
            $pdoStatement = $pdo->query($sql);
            $pdo = null;
            
            return $pdoStatement->fetch();
            
        } catch (PDOException $e) {
            die ( $e->getMessage() );
        }
    }// end loadStudentReords()

    function saveTranscriptRecord($id, $term, $grade) {
        try {
            require 'inc.db.php';
            
            // Connect to the database
            $pdo = new PDO(DSN, USER, PWD);
            
            // Configure error handling
            $pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
            
            // Create the query
            $sql = "
                UPDATE transcript 
                SET
                    term='$term', 
                    grade='$grade'
                WHERE id=$id
            ";
            
            // Execute the query.
            $result = $pdo->exec($sql);
            $pdo = null;
            
            return $result;

        } catch (PDOException $e) {
            die ( $e->getMessage() );
        }
    }// end saveTranscriptRecord()

    /* ----------------------------------------------------------------------------------------- */
    if ( $_SERVER['REQUEST_METHOD'] == 'GET' ) {
        
        $id = sanitizeInput($_GET['id']);
        $record = loadTranscriptRecord($id);

        $studentId = $record['studentId'];
        $courseId = $record['courseId'];
        $term = $record['term'];
        $grade = $record['grade'];

    } else {
        
        // Get the form field values. Trim and sanitize them first.
        $id = sanitizeInput($_POST['submit']);
        $term = sanitizeInput($_POST['term']);
        $grade = sanitizeInput($_POST['grade']);
   
        if ( $id == 0 ) {
            // Update is being canceled.
            header("Location: listTranscriptForm.php?rec=0");

        } else {
            // Updates are being saved.
            $isTermEmpty = empty($term);
            $isGradeEmpty = empty($grade);
            
            $hasFormEmptyFields =  $isTermEmpty || $isGradeEmpty;
            
            if ( !$hasFormEmptyFields ) {
                // First, we must save the changes to the DB.
                saveTranscriptRecord($id, $term, $grade);
                header("Location: editConfirm.php?record=transcript&recId=$id&editMode=update");
                
            } else {
                $formError = "Please fill out all the fields";
            }
        }
    } 
?>

<?php include 'inc.header.php'; ?>

<div class="w3-card w3-light-grey">
    <header class="w3-container w3-red w3-margin-top">
        <h1>Update Transcript Form</h1>
    </header>

    <form action="<?php echo $phpScript; ?>" method="POST">
        <div class="w3-container">
            <p> <!-- studentId - disabled -->
                <label class="w3-text-grey">Student Id</label>
                <input class="w3-input w3-border w3-light-grey" readonly accesskey="S" 
                       value="<?php echo $studentId; ?>">
            </p>
            <p> <!-- courseId - disabled -->
                <label class="w3-text-grey">Course Id</label>
                <input class="w3-input w3-border w3-light-grey" readonly accesskey="C" 
                       value="<?php echo $courseId; ?>">
            </p>
            <p> <!-- term -->
                <label for="term" class="w3-text-grey">Term</label>
                <span class="w3-text-red"> *</span>
                <input id="term" class="w3-input w3-border" accesskey="T" 
                       name="term" placeholder="e.g. 17SP" 
                       value="<?php echo $term; ?>" required>
            </p>
            <p> <!-- grade -->
                <label class="w3-text-grey">Grade</label>
                <span class="w3-text-red"> *</span>
                <input class="w3-input w3-border" accesskey="G" 
                       name="grade" placeholder="Grade" 
                       value="<?php echo $grade; ?>" required>
            </p>
        </div>

        <!-- Edit buttons -->
        <div class="w3-container w3-center">
            <p>
                <button name="submit" 
                        value="<?php echo $id; ?>"
                        class="w3-button w3-green">Save</button>
                <button name="submit" 
                        value="0" 
                        class="w3-button w3-red">Cancel</button>
            </p> 
        </div>
    </form>
</div>

<?php include 'inc.footer.php'; ?>