<?php
    // File: index.php
    /* Demonstrates the deleting of an instructor record
     * from the uni2 database.
    */

    declare(strict_types = 1);
    error_reporting(E_ALL);
    ini_set('display_errors', '1');

    function sanitizeInput($value) {
        return htmlspecialchars( stripslashes( trim( $value) ) );
    }

    function getPDO(): PDO {
        return new PDO('mysql:host=localhost;dbname=uni2', 'root', 'root');
    }

    function setuUni2pDB() {
        // We will establish a connection to the server and we will
        // set up the database if it does not exist. We will use
        // a batch query for this.
        $pdo = new PDO('mysql:host=localhost', 'root', 'root');
        $pdo->exec('USE uni2');

        // Check the errorCode for 42000 indicating the db is
        // not there.
        $errCode = $pdo->errorCode();
        if ($errCode == 42000) {
            // No uni2 database exists, so let's set it up.
            $sql = "CREATE DATABASE IF NOT EXISTS uni2;";

            // Next the istructor table.
            $sql .= "
            CREATE TABLE IF NOT EXISTS uni2.instructor (
                id INT UNSIGNED AUTO_INCREMENT NOT NULL,
                name VARCHAR(30),
                PRIMARY KEY(id)
            );
            ";

            // And finally insert two records.
            $sql .= "
            INSERT INTO uni2.instructor
            (name)
            VALUES
            ('Tornaritis'),
            ('Tetzner')
            ";
            $pdo->exec($sql) or die('Server error.');
            $pdo = null;
        }
    }

    function buildOptions(PDO $pdo) {
        $sql = "
        SELECT id, name
        FROM instructor
        ";

        foreach($pdo->query($sql, PDO::FETCH_ASSOC) as $instructor) {
            echo "
            <option value='{$instructor['id']}'>{$instructor['name']}</option>
            ";
        }
    }

    function displayInstructors(PDO $pdo) {
        $sql = "
        SELECT id, name
        FROM instructor
        ";

        echo "<h1>Current instructors</h1>";
        foreach($pdo->query($sql, PDO::FETCH_ASSOC) as $instructor) {
            echo "
            {$instructor['id']}, {$instructor['name']}<br>
            ";
        }
    }


    function deleteInstructor(PDO $pdo, string $id) {
        $sql = "
        DELETE
        FROM instructor
        WHERE id = $id
        ";
        $pdo->exec($sql);
        echo "Deleted instructor with id: $id.<br>";
    }

    $phpScript = sanitizeInput($_SERVER['PHP_SELF']);
    
    // Set up the uni2 database first, with its table and records.
    setuUni2pDB();

    $pdo = getPDO() or die("Server error.");
    
    if ($_SERVER['REQUEST_METHOD'] === 'POST') {
        try {
            $pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
            
            // Delete the instructor.
            deleteInstructor($pdo, sanitizeInput($_POST['instructorId']));
            
        } catch(PDOEXCEPTION $e) {
            // For debugging purposes reveal the message.
            die( $e->getMessage() );
        }
    }
    // List all current instructors.
    displayInstructors($pdo);
?>

<!-- Simplified for brevity only -->
<h1>Delete Instructor Form</h1>
<form action="<?php echo $phpScript; ?>" method="POST">
    <select name="instructorId">
        <?php buildOptions($pdo); $pdo = null; ?>
    </select>
    <button>Delete</button>
</form>