// File: js/index.js
//
// Use an IIFE to provide local scope.
( function() {
  let schedule = {
    CS240_001: { days: ['M', 'W','F'], time: '0800', durationInMinutes: 50, room: 'EB0140' },
    CS240_002: { days: ['M', 'W','F'], time: '1000', durationInMinutes: 50, room: 'EB0140' },
    CS234_002: { days: ['T', 'R'], time: '1400', durationInMinutes: 75, room: 'EB2160' },
    CS234_001: { days: ['T', 'R'], time: '1530', durationInMinutes: 75, room: 'EB1033' },
    O_H_: { days: ['M', 'T', 'W','R', 'F'], time: '1100', durationInMinutes: 60, room: 'EB3040' }
  };

  function addTableCellContent() {
    // Cycle through each key.
    for (let courseName in schedule) {
      let courseInfo = schedule[courseName];

      // Cycle through each value.
      for (let day of courseInfo.days) {
        // Build the 'id' attribute to search for below.
        let id = day + courseInfo.time;

        // Build the text content of the 'td' element.
        let contentHTML = `${courseName.replace(/_/g, '.')}<br>
                          ${courseInfo.room}<br>
                          ${courseInfo.durationInMinutes} min`;
        
        // Search the DOM tree for the specified id.
        let tdNode = document.getElementById(id);

        // Update its contentHTML and add a data-* (courseName) for easy access.
        tdNode.innerHTML = contentHTML;
        tdNode.setAttribute('data-course', courseName);
      }
    }
  };// end addTableCellContent()

  function registerDataCellHandlers() {
    let tdNodeList = document.getElementsByTagName('td');

    for (let tdNode of tdNodeList) {
      tdNode.addEventListener('mouseover', function() { 
        // this.classList.add('w3-light-blue');

        let dataCourseAttribute = tdNode.getAttribute('data-course');
        let courseNodeList = document.querySelectorAll(`[data-course=${dataCourseAttribute}]`);

        for (let courseNode of courseNodeList) {
          courseNode.classList.add('w3-light-blue');
        }
      });

      tdNode.addEventListener('mouseout', function()  { 
        // this.classList.remove('w3-light-blue'); 
        let dataCourseAttribute = tdNode.getAttribute('data-course');
        let courseNodeList = document.querySelectorAll(`[data-course=${dataCourseAttribute}]`);

        for (let courseNode of courseNodeList) {
          courseNode.classList.remove('w3-light-blue');
        }
      });
    }
  }


  addTableCellContent();
  registerDataCellHandlers();

})();