// File: js/index.js
'use strict';

$( function() {

    function tableCaption(monthName) {
        return `<caption>${monthName}</caption>`
    }

    function tableColHeaders() {
        let headerRow = '<tr style="width:10rem">';
        let className = '';

        for (let dayHeader of ['S', 'M', 'T', 'W', 'T', 'F', 'S']) {
            if (dayHeader == 'S') { className = 'wkend'; } 
            else                  { className = 'wkday'; }
            headerRow += `<th class="${className} w3-border" style="height:3rem">${dayHeader}</th>`;
        }
        headerRow += '</tr>';
        return headerRow;
    }

    function tableRows(days) {
        let dataRow = '';
        let className = '';

        for (let week of days) {
            dataRow += '<tr style="height:7rem">';
            
            week.forEach(function(day, dayIndex) {
                if (dayIndex == '0' || dayIndex == '6') { className = 'wkend'; } 
                else                                    { className = 'wkday'; }
                dataRow += `<td id="${day}" class="${className} w3-border" style="width:12%">${day.slice(1,3)}</td>`;
            });
            dataRow += '</tr>';
        }
        return dataRow;
    }

    function styleCaption(className) {
        let $captionElement = $('caption').addClass(className);
    }

    function styleWeekendHeaders(className) {
        $('th.wkend').addClass(className);
    }

    function styleWeekDayHeaders(className) {
        $('th.wkday').addClass(className);
    }
    
    function styleWeekendDataCells(className) {
        $('td.wkend').addClass(className);
    }

    function styleWeekDayDataCells(className) {
        $('td.wkday').addClass(className);
    }

    function setUpSpecialEventDays() {    
        // Set up the special event days in the month.
        let specialEventDay = ['p27', 'p31', 'c3', 'c11', 'c28'];
        let specialEvent = ['Diwali', 'Halloween', 'Daylight Saving Time', 'Veterans Day', 'Thanksgiving'];

        // for (let day of specialEventDay) {
        specialEventDay.forEach(function(day, dayIndex) {
            let $td = $(`#${day}`);
            let markup = '<span class="w3-text-red">&bull;</span>' + 
                         $td.html() + 
                         `<br><span class="w3-text-red w3-hide">${specialEvent[dayIndex]}</span>`;
            $td.html(markup);
        });
    }

    function registerMouseEvents() {
        // Register the mouseover event
        $('table').on('mouseover', function(e) {
            let $td = $(e.target);
            $td.find('span:eq(1)').removeClass('w3-hide');
        });

        $('#contentTable').on('mouseout', function(e) {
            $(e.target).find('span:eq(1)').addClass('w3-hide');
        });
    }




    /*---------------------------------------------------------*/
    let $contentTable = $('#contentTable');
    
    let tableContents = tableCaption('November 2019');
    tableContents += tableColHeaders();
    tableContents += tableRows([
        ['p27', 'p28', 'p29', 'p30', 'p31', 'c1', 'c2'], 
        ['c3', 'c4', 'c5', 'c6', 'c7', 'c8', 'c9'], 
        ['c10', 'c11', 'c12', 'c13', 'c14', 'c15', 'c16'], 
        ['c17', 'c18', 'c19', 'c20', 'c21', 'c22', 'c23'], 
        ['c24', 'c25', 'c26', 'c27', 'c28', 'c29', 'c30']
    ]);
    $contentTable.html( tableContents );
        
    // Style the table now.
    styleCaption('w3-khaki w3-large w3-panel w3-padding');
    styleWeekendHeaders('w3-light-gray w3-right-align');
    styleWeekDayHeaders('w3-khaki w3-right-align');
    styleWeekendDataCells('w3-light-gray w3-right-align');
    styleWeekDayDataCells('w3-right-align');

    setUpSpecialEventDays();
    registerMouseEvents();
});