<?php
    // File: listTranscript.php

    declare(strict_types = 1);
    error_reporting(E_ALL);
    ini_set('display_errors', '1');

    include 'inc.header.php';

    function transcriptList(PDOStatement $pdoStatement) : string {
        // Build the html with a table of student records.
        $table = '
            <table class="w3-table-all w3-hoverable w3-margin-top">
                <tr class="w3-red">
                    <th>Term</th>
                    <th>Course</th>
                    <th>Student</th>
                    <th>Grade</th>
                </tr>
        ';

        while ( $row = $pdoStatement->fetch() ) {
            $term = $row['term'];
            $course = $row['number'];
            $student = $row['name'];
            $grade = $row['grade'];

            $semester = ['1S' => 'Spring', '2S' => 'Summer', '3F' => 'Fall'];
            $semesterKey = substr($term, -2);
            $year = substr($term, 0, -2);
            $term = "$semester[$semesterKey] $year";
            
            $table .= "
                <tr>
                <td>$term</td>
                <td>$course</td>
                <td>$student</td>
                <td>$grade</td>
                </tr>
            ";
        }

        $table .= "</table>";
        return $table;
    }// end transcriptList()
    

    try {
        // Include the db connection script
        require 'inc.db.php';

        // Connect to the db.
        $pdo = new PDO(DSN, USER, PWD);

        // Configure error handling
        $pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);

        // Create the query
        $sql = '
            SELECT c.number, CONCAT(s.last, ", ", s.first) AS name, t.term, t.grade
            FROM course AS c, student AS s, transcript AS t
            WHERE c.id = t.course$id
            AND s.id = t.student$id
            ORDER BY t.term, c.number, name
        ';

        // Execute the query.
        $pdoStatement = $pdo->query($sql);
    
        // Display the records in a table.
        echo transcriptList($pdoStatement);
        $pdo = null;

    } catch(PDOException $e) {
        die ($e->getMessage() );
    }

    include 'inc.footer.php';
?>