<?php
    // File: addTranscriptForm.php
    declare(strict_types=1);
    error_reporting(E_ALL);
    ini_set('display_errors', '1');

    $sid = $number = $term = $grade = $formError = '';
    $pdo = getPDO();

    $curDate = date('Y');
    $phpScript = sanitizeInput($_SERVER['PHP_SELF']);


    function getPDO() : PDO {
        try {
            // Creates the PDO object to be used for DB interactions
            require_once 'inc.db.php';

            $pdo = new PDO(DSN, USER, PWD);
            $pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
            return $pdo;

        } catch(PDOException $e) {
            die;
        }
    }// end getPDO()


    function sanitizeInput($value) {
        return trim( stripslashes( htmlspecialchars($value) ) );
    }// end sanitizeInput()


    function saveTranscriptRecord($pdo, $sid, $number, $term, $grade) : bool {
        try {
            $sql = "
                INSERT INTO transcript
                  (student\$id, course\$id, term, grade)
                VALUES
                  ($sid, '$number', '$term', '$grade')
            ";

            $pdo->exec($sql);
            return true;

        } catch(PDOException $e) {
            return false;
        }
    }// end saveTranscriptRecord()


    function buildStudentSelect($pdo) {
        // Return the html that builds a <select>.
        try {
            $sql = '
                SELECT id, sid
                FROM student
                ORDER BY sid
            ';
            $rows = $pdo->query($sql);

            $dq = '"';
            $select = '<select name="sid" class="w3-input w3-border">';
            while ( $row = $rows->fetch() ) {
                $id = $row['id'];
                $sid = $row['sid'];
                $select .= "<option value=$dq$id$dq>$sid</option>";
            }
            $select .= '</select>';

        } catch(PDOException $e) {
            die( $e->getMessage() );
        }

        return $select;
    }// end buildStudentSelect()

    function buildNumberSelect($pdo) {
        try {
            $sql = '
                SELECT id, number
                FROM course
                ORDER BY number
            ';
            $rows = $pdo->query($sql);

            $dq = '"';
            $select = '<select name="number" class="w3-input w3-border">';
            while ( $row = $rows->fetch() ) {
                $id = $row['id'];
                $number = $row['number'];
                $select .= "<option value=$dq$id$dq>$number</option>";
            }
            $select .= '</select>';

        } catch(PDOException $e) {
            die( $e->getMessage() );
        }

        return $select;
    }// end buildNumberSelect()

    function buildTermSelect() {
        // Return the html that builds a <select>.
        $terms = ['1S', '2S', '3F'];
        $currentYear = date('y');

        $select = '<select name="term" class="w3-input w3-border">';
        for ($year = $currentYear; $year <= $currentYear + 1; $year++) {
            for ($termIndex = 0; $termIndex <= 2; $termIndex++) {
                $option = $year . $terms[$termIndex];

                $select .= "<option value=$option>$option</option>";
            }
        }
        $select .= '</select>';
        return $select;
    }// end buildTermSelect()

    function buildGradeSelect() {
        // Return the html that builds a <select>.
        $grades = ['A', 'B', 'C', 'D', 'F', 'I', 'NS', 'UW', 'WF', 'WP'];

        $select = '<select name="grade" class="w3-input w3-border">';
        $length = count($grades);

     
        for ($gradeIndex = 0; $gradeIndex <= $length - 1; $gradeIndex++) {
            $option = $grades[$gradeIndex];
            $select .= "<option value=$option>$option</option>";
        }
    
        $select .= '</select>';
        return $select;
    }// end buildGradeSelect()

    if ( $_SERVER['REQUEST_METHOD'] == 'POST' ) {
        // Get the form field values. Trim and sanitize them first.
        $sid = sanitizeInput($_POST['sid']);
        $number = sanitizeInput($_POST['number']);
        $term = sanitizeInput($_POST['term']);
        $grade  = sanitizeInput($_POST['grade']);

        $isSidEmpty = empty($sid);
        $isNumberEmpty = empty($number);
        $isTermEmpty = empty($term);
        $isGradeEmpty = empty($grade);

        $hasFormEmptyFields =  $isSidEmpty || $isNumberEmpty || $isTermEmpty || $isGradeEmpty;
        
        if ( !$hasFormEmptyFields ) {
            // Update the database.
            $status = saveTranscriptRecord($pdo, $sid, $number, $term, $grade);
            echo $status;

            if (  $status ) {
                // Show confirmation message
                header('Location: addConfirm.php?record=Transcript');

            } else {

                $formError = "Oops, saving error occurred.";
            }

        } else {
            $formError = "Please select an option for each field";
        }
    }
?>

<?php include 'inc.header.php'; ?>

<div class="w3-card w3-light-grey">
    <header class="w3-container w3-red w3-margin-top">
        <h1>Add Transcript Form</h1>
    </header>

    <form action="<?php echo $phpScript; ?>" method="POST" class="w3-container">
        <!-- FIX: Add a label and build its select -->
        <p> <!-- sid -->
            <label for="sid" class="w3-text-grey">SID</label>
            <?php echo buildStudentSelect($pdo)?>
        </p>

        <p> <!-- number -->
            <label for="number" class="w3-text-grey">Number</label>
            <?php echo buildNumberSelect($pdo)?>
        </p>

        <p> <!-- term -->
            <label for="term" class="w3-text-grey">Term</label>
            <?php echo buildTermSelect()?>
        </p>

        <p> <!-- grade -->
            <label for="grade" class="w3-text-grey">Grade</label>
            <?php echo buildGradeSelect()?>
        </p>

        <p> <!-- Save -->
            <button name="submit" class="w3-btn w3-red">
                Save
            </button>
            <span class="w3-text-red">
                <?php echo $formError; ?>
            </span>
        <p>
    </form>
</div>

<?php include 'inc.footer.php'; ?>