<?php
    // File: listStudentForm.php

    declare(strict_types = 1);
    error_reporting(E_ALL);
    ini_set('display_errors', '1');
    
    $recId = $sid = $fname = $lname = $email = '';

    $currentStudentIndex = sanitizeInput($_GET['rec']);
    $phpScript = sanitizeInput($_SERVER['PHP_SELF']);

    // Load the students from the DB each time. Ouch!
    $students = loadStudentRecords();

    $recCount = count($students);
    $nextStudentIndex = ($currentStudentIndex + 1) % $recCount;
    $previousStudentIndex = ($currentStudentIndex - 1 + $recCount) % $recCount;

    $firstRecRef = "$phpScript?rec=0";
    $prevtRecRef = "$phpScript?rec=$previousStudentIndex";
    $nextRecRef = "$phpScript?rec=$nextStudentIndex";
    $lastRecRef = "$phpScript?rec=" . ($recCount-1);

    prepareStudentRecord($currentStudentIndex, $students);

    function sanitizeInput($data) {
        return htmlspecialchars( stripslashes( trim($data) ) );
    }// end sanitizeInput()
    
    function loadStudentRecords() {
        try {
            include 'inc.db.php';

            // Connect to the database
            $pdo = new PDO(DSN, USER, PWD);
            
            // Configure error handling
            $pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
            
            // Create the queries
            $sql = '
                SELECT id, sid, first, last, email
                FROM student
                ORDER BY sid
            ';
            
            // Execute the query.
            $rows = $pdo->query($sql);
            $pdo = null;
            
            return $rows->fetchAll();
            
        } catch (PDOException $e) {
            die ( $e->getMessage() );
        }
    }// end loadStudentReords()
    
    
    function prepareStudentRecord($currentStudentIndex, $students) {
        $GLOBALS['recId'] = $students[$currentStudentIndex]['id'];
        $GLOBALS['sid'] = $students[$currentStudentIndex]['sid'];
        $GLOBALS['fname'] = $students[$currentStudentIndex]['first'];
        $GLOBALS['lname'] = $students[$currentStudentIndex]['last'];
        $GLOBALS['email'] = $students[$currentStudentIndex]['email'];
    }// end prepareStudentRecord()
    /* ----------------------------------------------------------------------------------------- */
?>


<?php include 'inc.header.php'; ?>

<div class="w3-card w3-light-grey">
    <header class="w3-container w3-red w3-margin-top">
        <h1>List Student Form</h1>
    </header>

    <div class="w3-container">
        <p> <!-- sid -->
            <label class="w3-text-grey">SID</label>
            <input class="w3-input w3-border" accesskey="S" readonly value="<?php echo $sid; ?>">
        </p>
        <p> <!-- first -->
            <label class="w3-text-grey">First</label>
            <input class="w3-input w3-border" accesskey="F" readonly value="<?php echo $fname; ?>">
        </p>
        <p> <!-- last -->
            <label class="w3-text-grey">Last</label>
            <input class="w3-input w3-border" accesskey="L" readonly value="<?php echo $lname; ?>">
        </p>
        <p> <!-- email -->
            <label class="w3-text-grey">Email</label>
            <input class="w3-input w3-border" accesskey="E" readonly value="<?php echo $email; ?>">
        </p>
    </div>

    <div class="w3-container w3-center">
        <p>
        <!-- Navigation buttons -->
        <a href="<?php echo $firstRecRef; ?>" class="w3-button w3-red">|&lt;</a>
        <a href="<?php echo $prevtRecRef; ?>" class="w3-button w3-red">&lt;&lt;</a>
        <a href="<?php echo $nextRecRef; ?>" class="w3-button w3-red">&gt;&gt;</a>
        <a href="<?php echo $lastRecRef; ?>" class="w3-button w3-red">&gt;|</a>

        <!-- Edit buttons -->
        <a href="<?php echo "deleteStudent.php?id=$recId"; ?>" 
        class="w3-button w3-red w3-right"> Delete</a>
        <a href="<?php echo "updateStudentForm.php?id=$recId"; ?>" 
        class="w3-button w3-green w3-right w3-margin-right"> Update</a>
        </p> 
    </div>
</div>

<?php include 'inc.footer.php'; ?>